# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   ${PROJECT_NAME}
# FileName:      ${FILE_NAME}
# Author:        shen
# Datetime:     ${DATE} ${TIME}
# Description:
#
# ---------------------------------------------------------------------------
import openpyxl

from APIAutoTest_shen_2 import log_decorator
from APIAutoTest_shen_2.common.read_basic_ini import ReadBasicIni
from APIAutoTest_shen_2.common.read_json import read_json
from APIAutoTest_shen_2.common.read_user_ini import ReadUserIni


class ReadExcel:
    @log_decorator
    def __init__(self,username):
        """获取excel和所有json文件的路径以及excel工作表的名称，获取工作薄和工作表，获取所有json文件数据对应的python对象"""
        #创建ReadBasicIni的对象，主要是用来获取被测系统的域名
        self.basic_ini = ReadBasicIni()
        #创建ReadUserIni的对象，来获取用户的数据
        self.ini = ReadUserIni(username)
        # 获取excel文件的路径和所有json文件的路径，获取工作表的名称
        case_data_path = self.ini.get_file_path("case")
        expect_data_path = self.ini.get_file_path("expect")
        excel_path = self.ini.get_file_path("excel")
        sql_data_path = self.ini.get_file_path("sql")
        table_name = self.ini.get_table_name("name")
        #获取工作薄和工作表
        #获取excel工作薄的路径
        wb = openpyxl.load_workbook(excel_path)
        #获取工作表
        self.ws = wb[table_name]


        #调用read_json函数，获取json文件的数据
        #获取用例文件的数据
        self.case_data_dict = read_json(case_data_path)
        #获取期望用例的数据
        self.expect_data_dict = read_json(expect_data_path)
        #获取sql语句的数据
        self.sql_data_dict = read_json(sql_data_path)
    @log_decorator
        #使用私有方法根据行和列获取单元格的数据
    def __get_cell_value(self,column,row):
        """根据行和列获取指定单元格的数据"""
        value = self.ws[column+str(row)].value
        #判断单元格数据是否不为none，如果不为none，将单元格数据去掉前后空格之后再返回，如果为none，将去掉空格为空的字符串返回none
        if isinstance(value,str) and value.strip():
            return value.strip()
    @log_decorator
    def module_name(self,row):
        """根据行，获取模块名称"""
        #调用私有方法__get_cell_value，根据行来获取模块名称
        return self.__get_cell_value("b",row)
    @log_decorator
    def api_name(self,row):
        """根据行，获取接口名称"""
        #调用私有方法__get_cell_value，根据行来获取接口名称
        return self.__get_cell_value("c",row)
    @log_decorator
    def case_url(self,row):
        """根据行，获取url"""
        # 调用私有方法__get_cell_value，根据行来获取url
        path = self.__get_cell_value("f",row)
        #判断路径是否不为none，如果不为none，和域名进行拼接
        if path:
            return self.basic_ini.get_host("bpm") + path

    @log_decorator
    def case_mime(self,row):
        """根据行，获取用例的媒体类型"""
        # 调用私有方法__get_cell_value，根据行来获取媒体类型
        mime = self.__get_cell_value("g",row)
        #判断媒体类型的值，如果不为none，全部转小写再返回
        if mime:
            return mime.lower()

    @log_decorator
    def case_req(self,row):
        """根据行获取用例的请求方法"""
        # 调用私有方法__get_cell_value，根据行来获取请求方法
        return self.__get_cell_value("h",row)

    @log_decorator
    def case_data(self,row):
        """根据行，获取用例的数据"""
        # 调用私有方法__get_cell_value，根据行来获取用例数据
        case_data_key = self.__get_cell_value("i",row)
        # 判断用例数据的key是否不为None，如果不为None，就提取用例数据，如果为None，就返回None
        if case_data_key:
            #获取模块名称
            module_name = self.module_name(row)
            #获取接口名称
            api_name = self.api_name(row)
            #提取用例数据并返回
            return self.case_data_dict[module_name][api_name][case_data_key]

    @log_decorator
    def expect_data(self,row):
        """根据行获取期望数据"""
        # 调用私有方法__get_cell_value，根据行来获取期望数据
        expect_data_key = self.__get_cell_value("j",row)
        #判断期望数据的key是否不为none，如果不为none，提取期望数据，如果为none，就返回none
        if expect_data_key:
            #获取模块名称
            module_name = self.module_name(row)
            api_name = self.api_name(row)
            #提取期望数据并返回
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    @log_decorator
    def sql_data(self,row):
        """根据行获取sql数据"""
        # 调用私有方法__get_cell_value，根据行来获取sql数据
        sql_data_key = self.__get_cell_value("l",row)
        #判断sql数据是否不为none，如果不为none，就提取数据，如果为none，就返回none
        if sql_data_key:
            #获取模块名称
            module_name = self.module_name(row)
            #获取接口名称
            api_name = self.api_name(row)
            #提取sql数据并返回
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    @log_decorator
    def sql_type(self,row):
        """根据行获取sql类型"""
        # 调用私有方法__get_cell_value，根据行来获取sql类型
        sql_statement =self.__get_cell_value("k",row)
        #判断sql语句类型的值是否不为none，如果不为none，就将值转小写再返回
        if sql_statement:
            return sql_statement.lower()


    @log_decorator
    def update_key(self,row):
        """根据行获取更新的值"""
        # 调用私有方法__get_cell_value，根据行来获取更新的值
        return self.__get_cell_value("m",row)

    @log_decorator
    def get_data(self):
        """获取所有的测试数据，放在二维列表中"""
        list_data = []
        for row in range(2,self.ws.max_row+1):
            url = self.case_url(row)
            mime = self.case_mime(row)
            req = self.case_req(row)
            case = self.case_data(row)
            expect = self.expect_data(row)
            sql = self.sql_data(row)
            sql_type1 = self.sql_type(row)
            update = self.update_key(row)
            #过滤空行
            if url is not None and req is not None and expect is not None:
                #将每行数据放在列表中，再将列表追加到之前创建的空列表中
                list_data.append([url,mime,req,case,expect,sql,sql_type1,update])
        else:
            return list_data

if __name__ == '__main__':
    excel = ReadExcel("zs")
    print(excel.get_data())































